@@ -603,7 +603,7 @@ update_feed_list_menu(newsreader_t* newsreader)
 
 	iFeedNo = 0;
 
-	DEBUG_PRINT("UpdateFeedListMenu Start");
+	DEBUG_PRINT("update_feed_list_menu Start");
 
 	if(newsreader->g_pFeedList){
 		for(pFeedList = newsreader->g_pFeedList->next; pFeedList; pFeedList = pFeedList->next){
@@ -711,8 +711,7 @@ update_feed_list_menu(newsreader_t* newsreader)
 	
 	gtk_menu_item_set_submenu(newsreader->wItmFeedList, menuFeedList);
 
-	DEBUG_PRINT("UpdateFeedListMenu End");
-
+	DEBUG_PRINT("update_feed_list_menu End");
 
 	return iFeedNo;
 }
